camelot.camelot.model.authentication.Country

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Country |
[hide private]
[frames] | no frames]

# Class Country

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
Inherited from `GeographicBoundary`: `__unicode__`

Class Methods | [hide private]
getOrCreate(cls, code, name) | source code

Class Variables | [hide private]
Inherited from `GeographicBoundary`: `code`, `name`